#include "tao/Flushing_Strategy.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Flushing_Strategy::~TAO_Flushing_Strategy ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
